@@ -3,8 +3,8 @@
 import tempfile
 
 from fabric.api import *
-from fabez.cmd import (cmd_git, cmd_ip, cmd_su)
 
+from fabez.cmd import *
 from server import *
 from io import *
 from perm import *
@@ -13,6 +13,7 @@ from pythonic import *
 from etc import *
 
 
+
 try:
     import pkg_resources  # in package
 except:
